<?php
session_start();

// Check if user is not logged in, redirect to login page
if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: login.php');
    exit;
}

// Check if form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $mobile = $_POST['mobile'];

    // Add +44 prefix if not already present
    if (strlen($mobile) == 10) {
        $mobile = "+44" . $mobile;
    }

    // Store the entered mobile number in session
    $_SESSION['mobile_number'] = $mobile;

    // Database connection details
    $dbHost = 'localhost';
    $dbName = 'cocoeatz_app';
    $dbUser = 'cocoeatz_test';
    $dbPassword = 'Msnt@786';

    try {
        // Connect to Database
        $db = new PDO("mysql:host=$dbHost;dbname=$dbName", $dbUser, $dbPassword);
        $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        // Fetch user details from the database
        $query = $db->prepare("SELECT id, f_name, l_name, wallet_balance FROM users WHERE phone = :mobile");
        $query->bindParam(':mobile', $mobile);
        $query->execute();
        $user = $query->fetch(PDO::FETCH_ASSOC);

        // If user exists, store user details in session and redirect to enter_amount.php
        if ($user) {
            $_SESSION['user_id'] = $user['id'];
            $_SESSION['user_name'] = $user['f_name'] . ' ' . $user['l_name'];
            $_SESSION['wallet_balance'] = $user['wallet_balance'];
            header('Location: enter_amount.php');
            exit;
        } else {
            $error = "User not found. Please try again.";
        }
    } catch (PDOException $e) {
        $error = "Database error: " . $e->getMessage();
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Enter Mobile Number</title>
    <style>
        /* Add your CSS styles here */
        body {
            font-family: Arial, sans-serif;
            background-color: #f2f2f2;
        }
        .container {
            width: 300px;
            margin: 0 auto;
            padding-top: 50px;
            text-align: center;
        }
        h2 {
            margin-bottom: 20px;
            font-size: 24px;
        }
        .error {
            color: red;
            margin-bottom: 20px;
            font-size: 18px;
        }
        label {
            display: block;
            margin-bottom: 10px;
            font-size: 18px;
        }
        input[type="tel"] {
            width: 100%;
            padding: 10px;
            margin-bottom: 20px;
            border: 1px solid #ccc;
            border-radius: 4px;
            box-sizing: border-box;
            font-size: 18px;
        }
        input[type="submit"] {
            width: 100%;
            padding: 10px;
            background-color: #4CAF50;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 18px;
        }
        input[type="submit"]:hover {
            background-color: #45a049;
        }
        .footer {
            position: fixed;
            bottom: 0;
            left: 0;
            width: 100%;
            background-color: #333;
            color: white;
            text-align: center;
            padding: 10px 0;
            font-size: 14px;
        }
    </style>
</head>
<body>
<div class="container">
    <h2>Enter Mobile Number</h2>
    <?php if (isset($error)) : ?>
        <p class="error"><?php echo $error; ?></p>
    <?php endif; ?>
    <form method="post" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>">
        <label for="mobile">Mobile Number:</label>
        <input type="tel" id="mobile" name="mobile" pattern="[0-9]{10}" required><br><br>
        <input type="submit" value="Submit">
    </form>
</div>
<div class="footer">
    &copy; <?php echo date("Y"); ?> Intoque Ltd.
</div>
</body>
</html>
