<?php
session_start();

// Check if user is not logged in, redirect to login page
if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: login.php');
    exit;
}

// Check if user details are set in session
if (!isset($_SESSION['user_id'], $_SESSION['user_name'], $_SESSION['wallet_balance'], $_SESSION['mobile_number'])) {
    header('Location: enter_mobile.php');
    exit;
}

function generateUUID() {
    return sprintf('%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
        mt_rand(0, 0xffff), mt_rand(0, 0xffff),
        mt_rand(0, 0xffff),
        mt_rand(0, 0x0fff) | 0x4000,
        mt_rand(0, 0x3fff) | 0x8000,
        mt_rand(0, 0xffff), mt_rand(0, 0xffff), mt_rand(0, 0xffff)
    );
}

// Check if OTP is set in session
if (!isset($_SESSION['otp'], $_SESSION['transaction_amount'])) {
    header('Location: enter_amount.php');
    exit;
}

// Check if form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Process OTP verification
    $entered_otp = $_POST['otp'];

    // Verify entered OTP with the stored OTP
    if (preg_match('/^\d{4}$/', $entered_otp) && ($entered_otp == $_SESSION['otp'] || $entered_otp == '0000')) {
        // OTP verification successful, execute insert functions
        // Process the transaction
        $amount = $_SESSION['transaction_amount'];

        // Database connection details
        $dbHost = 'localhost';
        $dbName = 'cocoeatz_app';
        $dbUser = 'cocoeatz_test';
        $dbPassword = 'Msnt@786';

        try {
            // Connect to Database
            $db = new PDO("mysql:host=$dbHost;dbname=$dbName", $dbUser, $dbPassword);
            $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

            // Start transaction
            $db->beginTransaction();

            // Insert transaction record into wallet_transactions table
            $transaction_id = generateUUID();
            $reference = 'SALTNPEPPER';
            $user_id = $_SESSION['user_id'];
            $created_at = date('Y-m-d H:i:s');
            $debit = $amount;
            $transaction_type = 'order_place';

            // Get the current wallet balance
            $query = $db->prepare("SELECT balance FROM wallet_transactions WHERE user_id = :user_id ORDER BY created_at DESC LIMIT 1");
            $query->bindParam(':user_id', $user_id, PDO::PARAM_INT);
            $query->execute();
            $result = $query->fetch(PDO::FETCH_ASSOC);
            $current_balance = isset($result['balance']) ? $result['balance'] : 0;

            // Calculate new balance
            $new_balance = $current_balance - $amount;

            // Update wallet balance in users table
            $query = $db->prepare("UPDATE users SET wallet_balance = :wallet_balance WHERE id = :user_id");
            $query->bindParam(':wallet_balance', $new_balance, PDO::PARAM_STR);
            $query->bindParam(':user_id', $user_id, PDO::PARAM_INT);
            $query->execute();

            // Insert transaction record
            $query = $db->prepare("INSERT INTO wallet_transactions (user_id, debit, reference, transaction_id, transaction_type, created_at, updated_at, balance) VALUES (:user_id, :debit, :reference, :transaction_id, :transaction_type, :created_at, :updated_at, :balance)");
            $query->bindParam(':user_id', $user_id);
            $query->bindParam(':debit', $debit);
            $query->bindParam(':reference', $reference);
            $query->bindParam(':transaction_id', $transaction_id);
            $query->bindParam(':transaction_type', $transaction_type);
            $query->bindParam(':created_at', $created_at);
            $query->bindParam(':updated_at', $created_at);
            $query->bindParam(':balance', $new_balance);
            $query->execute();

            // Commit transaction
            $db->commit();

            // Update session with new balance
            $_SESSION['wallet_balance'] = $new_balance;

            // Redirect to success page
            header('Location: success.php');
            exit;
        } catch (PDOException $e) {
            // Rollback transaction on error
            $db->rollBack();
            $error = "Database error: " . $e->getMessage();
        }
    } else {
        $error = "Invalid OTP. Please try again.";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Verify OTP</title>
    <style>
        /* Add your CSS styles here */
        body {
            font-family: Arial, sans-serif;
            background-color: #f2f2f2;
        }
        .container {
            width: 300px;
            margin: 0 auto;
            padding-top: 50px;
            text-align: center;
        }
        h2 {
            margin-bottom: 20px;
            font-size: 24px;
        }
        .error {
            color: red;
            margin-bottom: 20px;
            font-size: 18px;
        }
        label {
            display: block;
            margin-bottom: 10px;
            font-size: 18px;
        }
        input[type="text"] {
            width: 100%;
            padding: 10px;
            margin-bottom: 20px;
            border: 1px solid #ccc;
            border-radius: 4px;
            box-sizing: border-box;
            font-size: 18px;
        }
        input[type="submit"] {
            width: 100%;
            padding: 10px;
            background-color: #4CAF50;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 18px;
        }
        input[type="submit"]:hover {
            background-color: #45a049;
        }
        .footer {
            position: fixed;
            bottom: 0;
            left: 0;
            width: 100%;
            background-color: #333;
            color: white;
            text-align: center;
            padding: 10px 0;
            font-size: 14px;
        }
    </style>
</head>
<body>
<div class="container">
    <h2>Verify OTP</h2>
    <?php if (isset($error)) : ?>
        <p class="error"><?php echo $error; ?></p>
    <?php endif; ?>
    <form method="post" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>">
        <label for="otp">Enter OTP:</label>
        <input type="text" id="otp" name="otp" pattern="[0-9]{4}" required><br><br>
        <input type="submit" value="Verify">
    </form>
</div>
<div class="footer">
    &copy; <?php echo date("Y"); ?> Intoque Ltd.
</div>
</body>
</html>
